3 ms·
I'm excited that this seems to reduce the time needed to compile Python regex by over 50%, something which Python currently offers no way to speed up or paralle
by Alex3917 6y ago
I'm excited that this seems to reduce the time needed to compile Python regex by over 50%, something which Python currently offers no way to speed up or parallelize. You'd think that you'd be able to combine compiled regex to take advantage of repeated parts of patterns, or to compile regex across multiple processes and pickle them, but neither of those things are currently possible.